@@ -59,7 +59,7 @@ BEGIN {
         $ErrStr
     );
 
-    $VERSION = '2.08';
+    $VERSION = '2.09';
 
     XSLoader::load(__PACKAGE__, $VERSION);
 }
@@ -852,6 +852,10 @@ I<None>.
 
 =back
 
+=head1 KNOWN BUGS
+
+I<None>.
+
 =head1 CAVEATS
 
 =over 4
@@ -909,11 +913,11 @@ License or the Artistic License, as specified in the F<LICENCE> file.
 
 =head1 VERSION
 
-Version 2.08
+Version 2.09
 
 =head1 DATE
 
-31 Jul 2018
+08 Dec 2020
 
 =head1 HISTORY
 
